@@ -1,9 +1,6 @@
 package app
 
 import (
-	"bufio"
-	"bytes"
-	"io"
 	"os"
 	"path/filepath"
 	"strings"
@@ -13,6 +10,7 @@ import (
 	"github.com/google/go-cmp/cmp"
 	"github.com/stretchr/testify/require"
 	"github.com/variantdev/vals"
+	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/exectest"
 	ffs "github.com/helmfile/helmfile/pkg/filesystem"
@@ -48,35 +46,9 @@ func TestLint(t *testing.T) {
 			ReleasesMutex:        &sync.Mutex{},
 		}
 
-		bs := &bytes.Buffer{}
-
-		func() {
+		bs := runWithLogCapture(t, "debug", func(t *testing.T, logger *zap.SugaredLogger) {
 			t.Helper()
 
-			logReader, logWriter := io.Pipe()
-
-			logFlushed := &sync.WaitGroup{}
-			// Ensure all the log is consumed into `bs` by calling `logWriter.Close()` followed by `logFlushed.Wait()`
-			logFlushed.Add(1)
-			go func() {
-				scanner := bufio.NewScanner(logReader)
-				for scanner.Scan() {
-					bs.Write(scanner.Bytes())
-					bs.WriteString("\n")
-				}
-				logFlushed.Done()
-			}()
-
-			defer func() {
-				// This is here to avoid data-trace on bytes buffer `bs` to capture logs
-				if err := logWriter.Close(); err != nil {
-					panic(err)
-				}
-				logFlushed.Wait()
-			}()
-
-			logger := helmexec.NewLogger(logWriter, "debug")
-
 			valsRuntime, err := vals.New(vals.Options{CacheSize: 32})
 			if err != nil {
 				t.Errorf("unexpected error creating vals runtime: %v", err)
@@ -169,7 +141,7 @@ releases:
 			}
 
 			require.Equal(t, wantLints, helm.Linted)
-		}()
+		})
 
 		testNameComponents := strings.Split(t.Name(), "/")
 		testBaseName := strings.ToLower(
