@@ -1,14 +1,12 @@
 package app
 
 import (
-	"bufio"
-	"bytes"
-	"io"
 	"sync"
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/variantdev/vals"
+	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/exectest"
 	ffs "github.com/helmfile/helmfile/pkg/filesystem"
@@ -1026,32 +1024,8 @@ changing working directory back to "/path/to"
 				ReleasesMutex:        &sync.Mutex{},
 			}
 
-			bs := &bytes.Buffer{}
-
-			func() {
-				logReader, logWriter := io.Pipe()
-
-				logFlushed := &sync.WaitGroup{}
-				// Ensure all the log is consumed into `bs` by calling `logWriter.Close()` followed by `logFlushed.Wait()`
-				logFlushed.Add(1)
-				go func() {
-					scanner := bufio.NewScanner(logReader)
-					for scanner.Scan() {
-						bs.Write(scanner.Bytes())
-						bs.WriteString("\n")
-					}
-					logFlushed.Done()
-				}()
-
-				defer func() {
-					// This is here to avoid data-trace on bytes buffer `bs` to capture logs
-					if err := logWriter.Close(); err != nil {
-						panic(err)
-					}
-					logFlushed.Wait()
-				}()
-
-				logger := helmexec.NewLogger(logWriter, "debug")
+			bs := runWithLogCapture(t, "debug", func(t *testing.T, logger *zap.SugaredLogger) {
+				t.Helper()
 
 				valsRuntime, err := vals.New(vals.Options{CacheSize: 32})
 				if err != nil {
@@ -1125,7 +1099,7 @@ changing working directory back to "/path/to"
 						}
 					}
 				}
-			}()
+			})
 
 			if tc.log != "" {
 				actual := bs.String()
