@@ -2,8 +2,6 @@ package config
 
 // ChartsOptions is the options for the build command
 type ChartsOptions struct {
-	// Args is the args to pass to helm exec
-	Args string
 	// Set is the additional values to be merged into the command
 	Set []string
 	// Values is the additional value files to be merged into the command
@@ -36,11 +34,6 @@ func (c *ChartsImpl) Concurrency() int {
 	return c.ChartsOptions.Concurrency
 }
 
-// Args returns the args
-func (c *ChartsImpl) Args() string {
-	return c.ChartsOptions.Args
-}
-
 // IncludeTransitiveNeeds returns the includeTransitiveNeeds
 func (c *ChartsImpl) IncludeTransitiveNeeds() bool {
 	return false
