@@ -36,6 +36,7 @@ type execer struct {
 	logger               *zap.SugaredLogger
 	kubeContext          string
 	extra                []string
+	postRenderer         string
 	decryptedSecretMutex sync.Mutex
 	decryptedSecrets     map[string]*decryptedSecret
 	writeTempFile        func([]byte) (string, error)
@@ -142,6 +143,14 @@ func (helm *execer) SetEnableLiveOutput(enableLiveOutput bool) {
 	helm.enableLiveOutput = enableLiveOutput
 }
 
+func (helm *execer) SetPostRenderer(postRenderer string) {
+	helm.postRenderer = postRenderer
+}
+
+func (helm *execer) GetPostRenderer() string {
+	return helm.postRenderer
+}
+
 func (helm *execer) AddRepo(name, repository, cafile, certfile, keyfile, username, password string, managed string, passCredentials string, skipTLSVerify string) error {
 	var args []string
 	var out []byte
@@ -216,7 +225,7 @@ func (helm *execer) RegistryLogin(repository string, username string, password s
 	return err
 }
 
-func (helm *execer) BuildDeps(name, chart string) error {
+func (helm *execer) BuildDeps(name, chart string, flags ...string) error {
 	helm.logger.Infof("Building dependency release=%v, chart=%v", name, chart)
 	args := []string{
 		"dependency",
@@ -224,9 +233,7 @@ func (helm *execer) BuildDeps(name, chart string) error {
 		chart,
 	}
 
-	if helm.IsHelm3() {
-		args = append(args, "--skip-refresh")
-	}
+	args = append(args, flags...)
 
 	out, err := helm.exec(args, map[string]string{}, nil)
 	helm.info(out)
@@ -432,6 +439,7 @@ func (helm *execer) DiffRelease(context HelmContext, name, chart string, suppres
 		enableLiveOutput := false
 		overrideEnableLiveOutput = &enableLiveOutput
 	}
+
 	out, err := helm.exec(append(append(preArgs, "diff", "upgrade", "--allow-unreleased", name, chart), flags...), env, overrideEnableLiveOutput)
 	// Do our best to write STDOUT only when diff existed
 	// Unfortunately, this works only when you run helmfile with `--detailed-exitcode`
