@@ -93,6 +93,30 @@ func Test_SetEnableLiveOutput(t *testing.T) {
 	}
 }
 
+func Test_SetPostRenderer(t *testing.T) {
+	helm := MockExecer(NewLogger(os.Stdout, "info"), "dev")
+	if helm.enableLiveOutput {
+		t.Error("helmexec.enableLiveOutput should not be enabled by default")
+	}
+	postRendererFoo := "/bin/rewrite-repo.sh"
+	helm.SetPostRenderer(postRendererFoo)
+	if helm.postRenderer != postRendererFoo {
+		t.Errorf("helmexec.SetPostRenderer() - actual = %s expect = %s", helm.postRenderer, postRendererFoo)
+	}
+}
+
+func Test_GetPostRenderer(t *testing.T) {
+	helm := MockExecer(NewLogger(os.Stdout, "info"), "dev")
+	if helm.enableLiveOutput {
+		t.Error("helmexec.enableLiveOutput should not be enabled by default")
+	}
+	postRendererFoo := "/bin/rewrite-repo.sh"
+	helm.SetPostRenderer(postRendererFoo)
+	if helm.GetPostRenderer() != postRendererFoo {
+		t.Errorf("helmexec.GetPostRenderer() - actual = %s expect = %s", helm.GetPostRenderer(), postRendererFoo)
+	}
+}
+
 func Test_AddRepo_Helm_3_3_2(t *testing.T) {
 	var buffer bytes.Buffer
 	logger := NewLogger(&buffer, "debug")
@@ -339,7 +363,7 @@ func Test_BuildDeps(t *testing.T) {
 	logger := NewLogger(&buffer, "debug")
 	helm3Runner := mockRunner{output: []byte("v3.2.4+ge29ce2a")}
 	helm := New("helm", false, logger, "dev", &helm3Runner)
-	err := helm.BuildDeps("foo", "./chart/foo")
+	err := helm.BuildDeps("foo", "./chart/foo", []string{"--skip-refresh"}...)
 	expected := `Building dependency release=foo, chart=./chart/foo
 exec: helm --kube-context dev dependency build ./chart/foo --skip-refresh
 v3.2.4+ge29ce2a
@@ -352,9 +376,22 @@ v3.2.4+ge29ce2a
 	}
 
 	buffer.Reset()
-	helm.SetExtraArgs("--verify")
 	err = helm.BuildDeps("foo", "./chart/foo")
 	expected = `Building dependency release=foo, chart=./chart/foo
+exec: helm --kube-context dev dependency build ./chart/foo
+v3.2.4+ge29ce2a
+`
+	if err != nil {
+		t.Errorf("unexpected error: %v", err)
+	}
+	if buffer.String() != expected {
+		t.Errorf("helmexec.BuildDeps()\nactual = %v\nexpect = %v", buffer.String(), expected)
+	}
+
+	buffer.Reset()
+	helm.SetExtraArgs("--verify")
+	err = helm.BuildDeps("foo", "./chart/foo", []string{"--skip-refresh"}...)
+	expected = `Building dependency release=foo, chart=./chart/foo
 exec: helm --kube-context dev dependency build ./chart/foo --skip-refresh --verify
 v3.2.4+ge29ce2a
 `
