@@ -21,6 +21,7 @@ helmfile="./helmfile ${EXTRA_HELMFILE_FLAGS} --namespace=${test_ns}"
 helm="helm --kube-context=minikube"
 kubectl="kubectl --context=minikube --namespace=${test_ns}"
 helm_dir="${PWD}/${dir}/.helm"
+cases_dir="${dir}/test-cases"
 export HELM_DATA_HOME="${helm_dir}/data"
 export HELM_HOME="${HELM_DATA_HOME}"
 export HELM_PLUGINS="${HELM_DATA_HOME}/plugins"
@@ -79,7 +80,7 @@ fi
 ${helm} plugin ls | grep diff || ${helm} plugin install https://github.com/databus23/helm-diff --version v${HELM_DIFF_VERSION}
 info "Using Kustomize version: $(kustomize version --short | grep -o 'v[0-9.]\+')"
 ${kubectl} get namespace ${test_ns} &> /dev/null && warn "Namespace ${test_ns} exists, from a previous test run?"
-$kubectl create namespace ${test_ns} || fail "Could not create namespace ${test_ns}"
+${kubectl} create namespace ${test_ns} || fail "Could not create namespace ${test_ns}"
 
 
 # TEST CASES----------------------------------------------------------------------------------------------------------
@@ -89,6 +90,7 @@ $kubectl create namespace ${test_ns} || fail "Could not create namespace ${test_
 . ${dir}/test-cases/secretssops.sh
 . ${dir}/test-cases/yaml-overwrite.sh
 . ${dir}/test-cases/chart-needs.sh
+. ${dir}/test-cases/postrender-diff.sh
 
 # ALL DONE -----------------------------------------------------------------------------------------------------------
 
